@@ -15,6 +15,7 @@
 # limitations under the License.
 #
 
+from h2o.utils.typechecks import assert_is_type
 from pyspark.ml.param import *
 from pyspark.ml.wrapper import JavaWrapper
 
@@ -24,57 +25,41 @@ class H2OMOJOSettings(JavaWrapper):
     def __init__(self,
                  predictionCol="prediction",
                  detailedPredictionCol="detailed_prediction",
+                 withDetailedPredictionCol=False,
                  convertUnknownCategoricalLevelsToNa=False,
                  convertInvalidNumbersToNa=False,
                  namedMojoOutputColumns=True,
                  withContributions=False,
-                 withInternalContributions=False,
-                 withPredictionInterval=False,
-                 withLeafNodeAssignments=False,
-                 withStageResults=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
-                 scoringBulkSize=1000):
+                 withLeafNodeAssignments=False):
         self._java_obj = None
 
-        assert isinstance(predictionCol, str)
-        assert isinstance(detailedPredictionCol, str)
-        assert isinstance(convertUnknownCategoricalLevelsToNa, bool)
-        assert isinstance(convertInvalidNumbersToNa, bool)
-        assert isinstance(namedMojoOutputColumns, bool)
-        assert isinstance(withContributions, bool)
-        assert isinstance(withInternalContributions, bool)
-        assert isinstance(withPredictionInterval, bool)
-        assert isinstance(withLeafNodeAssignments, bool)
-        assert isinstance(withStageResults, bool)
-        assert isinstance(dataFrameSerializer, str)
-        assert isinstance(scoringBulkSize, int)
+        assert_is_type(predictionCol, str)
+        assert_is_type(detailedPredictionCol, str)
+        assert_is_type(withDetailedPredictionCol, bool)
+        assert_is_type(convertUnknownCategoricalLevelsToNa, bool)
+        assert_is_type(convertInvalidNumbersToNa, bool)
+        assert_is_type(namedMojoOutputColumns, bool)
+        assert_is_type(withContributions, bool)
+        assert_is_type(withLeafNodeAssignments, bool)
         self.predictionCol = predictionCol
         self.detailedPredictionCol = detailedPredictionCol
+        self.withDetailedPredictionCol = withDetailedPredictionCol
         self.convertUnknownCategoricalLevelsToNa = convertUnknownCategoricalLevelsToNa
         self.convertInvalidNumbersToNa = convertInvalidNumbersToNa
         self.namedMojoOutputColumns = namedMojoOutputColumns
         self.withContributions = withContributions
-        self.withInternalContributions = withInternalContributions
-        self.withPredictionInterval = withPredictionInterval
         self.withLeafNodeAssignments = withLeafNodeAssignments
-        self.withStageResults = withStageResults
-        self.dataFrameSerializer = dataFrameSerializer
-        self.scoringBulkSize = scoringBulkSize
 
     def toJavaObject(self):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.models.H2OMOJOSettings",
                                             self.predictionCol,
                                             self.detailedPredictionCol,
+                                            self.withDetailedPredictionCol,
                                             self.convertUnknownCategoricalLevelsToNa,
                                             self.convertInvalidNumbersToNa,
                                             self.namedMojoOutputColumns,
                                             self.withContributions,
-                                            self.withInternalContributions,
-                                            self.withPredictionInterval,
-                                            self.withLeafNodeAssignments,
-                                            self.withStageResults,
-                                            self.dataFrameSerializer,
-                                            self.scoringBulkSize)
+                                            self.withLeafNodeAssignments)
         return self._java_obj
 
     @staticmethod
